==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/ReverseEngineering/Gui/Resources/translations/ReverseEngineering_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Reverse Engineering</source>
      <translation>Обратный инжиниринг</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>Приблизительная плоскость...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>Аппроксимировать плоскость</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-37"/>
      <source>Reverse Engineering</source>
      <translation>Обратный инжиниринг</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate B-spline surface...</source>
      <translation type="unfinished">Approximate B-spline surface...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-spline surface</source>
      <translation type="unfinished">Approximate a B-spline surface</translation>
    </message>
    <message>
      <source>Approximate B-Spline surface...</source>
      <translation>Приблизительная B-сплайновая поверхность...</translation>
    </message>
    <message>
      <source>Approximate surface...</source>
      <translation>Апроксимация поверхности...</translation>
    </message>
    <message>
      <source>Approximate a B-Spline surface</source>
      <translation>Апроксимировать поверхность B-сплайна</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location line="+134"/>
      <source>Reverse Engineering</source>
      <translation>Обратный инжиниринг</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson...</source>
      <translation>Poisson...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson surface reconstruction</source>
      <translation>Реконструкция поверхности Пуассона</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location line="+32"/>
      <source>Reverse Engineering</source>
      <translation>Обратный инжиниринг</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Structured point clouds</source>
      <translation>Структурированные точки облака</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Triangulation of structured point clouds</source>
      <translation>Триангуляция облаков точек структурированных</translation>
    </message>
    <message>
      <source>View triangulation</source>
      <translation type="unfinished">View triangulation</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <source>Fit B-Spline surface</source>
      <translation>Fit B-сплайновая поверхность</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="+14"/>
      <source>Fit B-spline surface</source>
      <translation type="unfinished">Fit B-spline surface</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>u-Direction</source>
      <translation>u направление</translation>
    </message>
    <message>
      <location line="+6"/>
      <location line="+67"/>
      <source>Degree</source>
      <translation>Степень</translation>
    </message>
    <message>
      <location line="-38"/>
      <location line="+67"/>
      <source>Control points</source>
      <translation>Контрольные точки</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>v-Direction</source>
      <translation>u направление</translation>
    </message>
    <message>
      <location line="+67"/>
      <source>Settings</source>
      <translation>Настройки</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Iterations</source>
      <translation>Итерации</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Size factor</source>
      <translation>Коэффициент размера</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Smoothing</source>
      <translation>Размытие</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Total Weight</source>
      <translation>Общий вес</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Length of gradient</source>
      <translation>Длина градиента</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Bending energy</source>
      <translation>Изгиб энергии</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Curvature variation</source>
      <translation>Вариация кривизны</translation>
    </message>
    <message>
      <location line="+32"/>
      <source>User-defined u/v directions</source>
      <translation>Определяемые пользователем u/v направления</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="+146"/>
      <source>Wrong selection</source>
      <translation>Неправильный выбор</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>Пожалуйста, выберите один размещение объекта для получения местной ориентации.</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Input error</source>
      <translation>Ошибка ввода</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="+14"/>
      <source>Poisson</source>
      <translation>Пуассона</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Parameters</source>
      <translation>Параметры</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Octree depth</source>
      <translation>Октодерево глубина</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Solver divide</source>
      <translation>Механизм расчета разрыва</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Samples per node</source>
      <translation>Образцы каждого узла</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="+109"/>
      <source>Input error</source>
      <translation>Ошибка ввода</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="-159"/>
      <location line="+135"/>
      <source>Wrong selection</source>
      <translation>Неправильный выбор</translation>
    </message>
    <message>
      <location line="-134"/>
      <location line="+135"/>
      <source>Please select a single point cloud.</source>
      <translation>Пожалуйста, выберите одну точку облака.</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location line="+55"/>
      <source>View triangulation failed</source>
      <translation>Просмотр триангуляции не удалось</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>Обратный инжиниринг</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/ReverseEngineering/Gui/Resources/translations/ReverseEngineering_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Reverse Engineering</source>
      <translation>Обратный инжиниринг</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>Приблизительная плоскость...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>Аппроксимировать плоскость</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-37"/>
      <source>Reverse Engineering</source>
      <translation>Обратный инжиниринг</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate B-spline surface...</source>
      <translation>Апроксимировать поверхность B-сплайна...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-spline surface</source>
      <translation>Апроксимировать поверхность B-сплайна</translation>
    </message>
    <message>
      <source>Approximate B-Spline surface...</source>
      <translation>Приблизительная B-сплайновая поверхность...</translation>
    </message>
    <message>
      <source>Approximate surface...</source>
      <translation>Апроксимация поверхности...</translation>
    </message>
    <message>
      <source>Approximate a B-Spline surface</source>
      <translation>Апроксимировать поверхность B-сплайна</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location line="+134"/>
      <source>Reverse Engineering</source>
      <translation>Обратный инжиниринг</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson...</source>
      <translation>Пуассона...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson surface reconstruction</source>
      <translation>Реконструкция поверхности Пуассона</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location line="+32"/>
      <source>Reverse Engineering</source>
      <translation>Обратный инжиниринг</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Structured point clouds</source>
      <translation>Облака структурированных точек</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Triangulation of structured point clouds</source>
      <translation>Триангуляция облаков структурированных точек</translation>
    </message>
    <message>
      <source>View triangulation</source>
      <translation type="unfinished">View triangulation</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <source>Fit B-Spline surface</source>
      <translation>Разместить B-сплайновую поверхность</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="+14"/>
      <source>Fit B-spline surface</source>
      <translation>Разместить B-сплайновую поверхность</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>u-Direction</source>
      <translation>u направление</translation>
    </message>
    <message>
      <location line="+6"/>
      <location line="+67"/>
      <source>Degree</source>
      <translation>Градусы</translation>
    </message>
    <message>
      <location line="-38"/>
      <location line="+67"/>
      <source>Control points</source>
      <translation>Контрольные точки</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>v-Direction</source>
      <translation>v направление</translation>
    </message>
    <message>
      <location line="+67"/>
      <source>Settings</source>
      <translation>Настройки</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Iterations</source>
      <translation>Итерации</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Size factor</source>
      <translation>Масштабирование</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Smoothing</source>
      <translation>Сглаживание</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Total Weight</source>
      <translation>Общий вес</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Length of gradient</source>
      <translation>Длина градиента</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Bending energy</source>
      <translation>Энергия изгиба</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Curvature variation</source>
      <translation>Варианты кривизны</translation>
    </message>
    <message>
      <location line="+32"/>
      <source>User-defined u/v directions</source>
      <translation>Пользовательские u/v направления</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="+146"/>
      <source>Wrong selection</source>
      <translation>Неправильный выбор</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>Пожалуйста, выберите один объект размещения для получения локальной ориентации.</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Input error</source>
      <translation>Ошибка ввода</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="+14"/>
      <source>Poisson</source>
      <translation>Пуассона</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Parameters</source>
      <translation>Параметры</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Octree depth</source>
      <translation>Глубина октодерева</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Solver divide</source>
      <translation>Решатель разделения</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Samples per node</source>
      <translation>Количество дискретных элементов на узел</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="+109"/>
      <source>Input error</source>
      <translation>Ошибка ввода</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="-159"/>
      <location line="+135"/>
      <source>Wrong selection</source>
      <translation>Неправильный выбор</translation>
    </message>
    <message>
      <location line="-134"/>
      <location line="+135"/>
      <source>Please select a single point cloud.</source>
      <translation>Пожалуйста, выберите одну точку облака.</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location line="+55"/>
      <source>View triangulation failed</source>
      <translation>Просмотр непросчитанной триангуляции</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>Обратный инжиниринг</translation>
    </message>
  </context>
</TS>
